if [ $# -eq 0 ]; then
    echo "Please pass a path to the qcow2 image"
    exit 1
fi

if [ "$EUID" -ne 0 ]
  then echo "This script must be run as root due to the use of guestmount and docker."
  exit 1
fi

if ! command -v guestmount &> /dev/null
then
    echo "guestmount could not be found; please install libguestfs-tools."
    exit 1
fi

if ! command -v docker &> /dev/null
then
    echo "docker could not be found; please install docker."
    exit 1
fi

echo "Welcome to the GitHub Enterprise Server image modification script."
echo "This script will modify the image to be licensed for use with GitHub Enterprise Server."
echo "\n\n" # newline

echo "Mounting the image..."
mkdir -p ./tmp
guestmount -a $1 ./tmp -i

echo "Generating license gpg keys"
cd ../licensing
./generate_keys.sh

echo "Returning to andromeda"
cd ../qcow2-mod

GH_IMG_LOC=`find ./tmp/data/docker-images/ -name "github:*" | head -n 1 | cut -d "/" -f 5`
echo "Found image: $GH_IMG_LOC.. Copying."
mkdir -p "../docker-images/official-images"
cp "./tmp/data/docker-images/$GH_IMG_LOC" "../docker-images/official-images/$GH_IMG_LOC"
echo "Copied image"
echo "Copying vault file"
VAULT_FILE_LOC=`find ./tmp/data/enterprise-manage -name "vault.rb" | head -n 1`
cp "$VAULT_FILE_LOC" "../docker-images/github/vault.rb"
cd ../docker-images
./setup.sh

cd ../qcow2-mod
NEW_GH_IMG_LOC=`find ../docker-images/modified-images -name "github:*" | head -n 1 | cut -d "/" -f 4`
NEW_GH_IMG_ID=`echo $NEW_GH_IMG_LOC | cut -d "#" -f 2 | cut -d "." -f 1`
echo "Docker image built. Copying back to qcow."
cp "../docker-images/modified-images/$NEW_GH_IMG_LOC" "./tmp/data/docker-images/$NEW_GH_IMG_LOC"
echo "Removing old Docker image."
rm "./tmp/data/docker-images/$GH_IMG_LOC"

echo "Setting hash."
echo "$NEW_GH_IMG_ID" > ./tmp/data/docker-image-tags/github_image_id

echo "Copying over license keys"
cp ../licensing/image_keys/enterprise/customer.gpg ./tmp/data/enterprise/customer.gpg
cp ../licensing/image_keys/enterprise/license.gpg ./tmp/data/enterprise/license.gpg
cp ../licensing/image_keys/enterprise/package.gpg ./tmp/data/enterprise/package.gpg

echo "Copying over vault file for enterprise-manage"
cp "../docker-images/github/vault.rb.new" "$VAULT_FILE_LOC"
guestunmount ./tmp
rm -rf ./tmp

echo "Done. You can now use ../create_license.sh to create a license for this image."